<?php

namespace Drupal\permissions_view_only\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\filter_perms\Form\PermissionsForm;

/**
 * Provides an enhanced user permissions administration form.
 */
class ViewUserPermissionsForm extends PermissionsForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    // Remove the max input vars warning count.
    $this->messenger()->deleteAll();

    // Remove submit buttons.
    unset($form['actions']);

    // Change to unicode checkmark instead of form inputs.
    if (!empty($form['permissions'])) {
      foreach ($form['permissions'] as &$module_permissions) {
        if (!is_array($module_permissions)) {
          continue;
        }

        foreach ($module_permissions as &$permission) {
          if (!is_array($permission) || !isset($permission['#type']) || $permission['#type'] !== 'checkbox') {
            continue;
          }

          $permission = [
            '#title' => $permission['#title'] ?? '',
            '#title_display' => $permission['#title_display'] ?? '',
            '#markup' => $permission['#default_value'] ? '✓' : '&nbsp;',
          ];
        }
      }
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Do nothing. Just prevent inadvertently letting users access submit out
    // of an abundance of caution.
  }

}
