<?php

namespace Drupal\Tests\permissions_view_only\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\user\UserInterface;

/**
 * Contains Permissions View Only functionality tests.
 *
 * @group permissions_view_only
 */
class PermissionsViewOnlyTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'permissions_view_only',
    'user',
    'filter_perms',
    'system',
    'menu_ui',
    'block',
    'toolbar',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';


  /**
   * Admin.
   *
   * @var \Drupal\user\UserInterface
   */
  protected UserInterface $admin;

  /**
   * View permissions only.
   *
   * @var \Drupal\user\UserInterface
   */
  protected UserInterface $editor;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalPlaceBlock('local_tasks_block', ['id' => 'tabs_block']);
    $this->admin = $this->drupalCreateUser([], NULL, TRUE);
    $this->editor = $this->drupalCreateUser([
      'view permissions list',
      'view the administration theme',
      'administer users',
    ]);
  }

  /**
   * Tests activating a blocked user.
   */
  public function testPermissions() {
    $this->drupalLogin($this->admin);
    $this->drupalGet('admin/people');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->linkExistsExact('Permissions Overview');
    $this->assertSession()->linkExistsExact('Permissions');

    $this->drupalLogout();
    $this->drupalLogin($this->editor);
    $this->drupalGet('admin/people');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->linkExistsExact('Permissions Overview');
    $this->assertSession()->linkNotExistsExact('Permissions');

    $this->drupalGet('admin/people/permissions-overview');
    $this->assertSession()->statusCodeEquals(200);
    $this->submitForm([
      'roles[]' => ['-1'],
      'modules[]' => ['-1'],
    ], 'Filter Permissions');
    $this->assertSession()->pageTextContains('✓');
  }

}
